@@ -1,9 +1,11 @@
 import re
 import sys
+from pprint import pprint
+from datetime import datetime
 
-from criteo_api_sdk.api.analytics_api import AnalyticsApi
-from criteo_api_sdk.models import StatisticsReportQueryMessage
-from criteo_api_sdk import Configuration, ApiClient
+from criteo_api_retailmedia_preview.api.analytics_api import AnalyticsApi
+from criteo_api_retailmedia_preview.models import StatisticsReportQueryMessage
+from criteo_api_retailmedia_preview import Configuration, ApiClient
 
 if __name__ == '__main__':
     if len(sys.argv) != 3:
@@ -17,15 +19,12 @@ if __name__ == '__main__':
     stats_query_message = StatisticsReportQueryMessage(
         dimensions=["AdsetId"],
         metrics=["Clicks"],
-        start_date="2019-01-01",
-        end_date="2019-01-31",
+        start_date=datetime.strptime("2022-07-01", '%Y-%m-%d'),
+        end_date=datetime.strptime("2022-07-31", '%Y-%m-%d'),
         currency="EUR",
         format="Csv")
 
     # Use the method with 'with_http_info' if you want to retrieve the filename
     # Otherwise, you can directly call the get_adset_report method
-    [response_content, http_code, response_headers] = api.get_adset_report_with_http_info(statistics_report_query_message=stats_query_message)
-    if 200 == http_code:
-        content_disposition = response_headers["Content-Disposition"]
-        if content_disposition:
-            print(response_content)
+    response_content = api.get_adset_report(statistics_report_query_message=stats_query_message)
+    pprint(response_content)
